

set -ex



test -L $PREFIX/lib/libnvrtc.so.12
test -L $PREFIX/lib/libnvrtc.so.12.6.20
test -L $PREFIX/targets/sbsa-linux/lib/libnvrtc.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libnvrtc.so.12.6.20
exit 0
